import { Component } from '@angular/core';
import { Platform } from '@ionic/angular';
import { SplashScreen } from "@awesome-cordova-plugins/splash-screen";

declare var window: any;

@Component({
  selector: 'app-home',
  templateUrl: 'home.page.html',
  styleUrls: ['home.page.scss'],
})
export class HomePage {

  device: any = {};
  scan: boolean = false;
  button: any = {
    title: '开始扫描'
  };
  epcs: any[] = [];

  constructor(private platform : Platform) {

    // 接收连续读卡时的数据
    window.addEventListener('ubxrfid', (info: any) => {
      console.log('received epc: ', JSON.stringify(info));
      let exist = false;
      for (const e of this.epcs) {
        if (e.epc === info.epc) {
          exist = true;
          e.count++;
        }
      }
      if (!exist) {
        this.epcs.push({ epc: info.epc, count: 1 });
      }
    });

    this.platform.ready().then(() => {
      SplashScreen.hide();
      window.cordova.plugin.ubxRfid.getDeviceInfo().then(
        (info:any) => {
          this.device = info;
          console.log('getDeviceInfo: ', JSON.stringify(this.device));
        },
        this.errorInfo
      )
    });
  }

  errorInfo(err: string) {
    alert(err);
  }

  toggleScan() {
    if (this.scan) {
      this.button.title = '开始扫描';
      this.scan = false;
      window.cordova.plugin.ubxRfid.stopSearchCard().then( (
        msg: string) => {
          console.log('stopSearchCard: ', msg);
        },
        this.errorInfo
      );
    }
    else {
      this.epcs = [];
      this.button.title = '停止扫描';
      this.scan = true;
      window.cordova.plugin.ubxRfid.startSearchCard().then(
        this.receiveResult,
        this.errorInfo
      );
    }
  }

  receiveResult(epc: any) {
    console.log('epc result: ', JSON.stringify(epc));
  }

  getPower() {
    window.cordova.plugin.ubxRfid.getPower().then(
      (power: any) => {
        console.log('rfid power: ', power);
        this.device.power = power;
      },
      this.errorInfo
    );
  }

  setPower() {
    window.cordova.plugin.ubxRfid.setPower(this.device.power).then(
      () => {
        console.log(`set power ${this.device.power} succeess.........`);
      },
      this.errorInfo
    );
  }

  getScanInterval() {
    window.cordova.plugin.ubxRfid.getScanInterval().then(
      (scanInterval: any) => {
        console.log('rfid scanInterval: ', scanInterval);
        this.device.scanInterval = scanInterval;
      },
      this.errorInfo
    );
  }

  setScanInterval() {
    window.cordova.plugin.ubxRfid.setScanInterval(this.device.scanInterval).then(
      () => {
        console.log(`set scanInterval ${this.device.scanInterval} succeess.........`);
      },
      this.errorInfo
    );
  }

  searchCard() {
    window.cordova.plugin.ubxRfid.searchCard().then(
      (epc: any) => {
        console.log('rfid epc result: ', epc);
        this.device.epc = epc;
      },
      this.errorInfo
    );
  }

  toggleBeep() {
    this.device.beep = !this.device.beep;
    window.cordova.plugin.ubxRfid.setBeep(this.device.beep);
  }

}
